@@ -6,7 +6,7 @@ use warnings;
 use Moo;
 use MooX::Types::MooseLike::Base qw/ ArrayRef HashRef Int Str /;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use Data::Dump 'dump';
 use DateTime;
@@ -571,22 +571,23 @@ sub _construct_event {
     my ($self, %context) = @_;
 
     my $event = {
-        event_id    => $context{event_id}    || $self->context()->{event_id}    || _generate_id(),
-        timestamp   => $context{timestamp}   || $self->context()->{timestamp}   || DateTime->now()->iso8601(),
-        logger      => $context{logger}      || $self->context()->{logger}      || 'root',
-        server_name => $context{server_name} || $self->context()->{server_name} || hostname(),
-        platform    => $context{platform}    || $self->context()->{platform}    || 'perl',
+        event_id        => $context{event_id}    || $self->context()->{event_id}    || _generate_id(),
+        timestamp       => $context{timestamp}   || $self->context()->{timestamp}   || DateTime->now()->iso8601(),
+        logger          => $context{logger}      || $self->context()->{logger}      || 'root',
+        server_name     => $context{server_name} || $self->context()->{server_name} || hostname(),
+        platform        => $context{platform}    || $self->context()->{platform}    || 'perl',
 
-        release     => $context{release}     || $self->context()->{release},
+        release         => $context{release}     || $self->context()->{release},
 
-        message     => $context{message}     || $self->context()->{message},
-        culprit     => $context{culprit}     || $self->context()->{culprit},
+        message         => $context{message}     || $self->context()->{message},
+        culprit         => $context{culprit}     || $self->context()->{culprit},
 
-        extra       => $self->_merge_hashrefs($self->context()->{extra}, $context{extra}),
-        tags        => $self->_merge_hashrefs($self->context()->{tags}, $context{tags}),
-        fingerprint => $context{fingerprint} || $self->context()->{fingerprint} || ['{{ default }}'],
+        extra           => $self->_merge_hashrefs($self->context()->{extra}, $context{extra}),
+        tags            => $self->_merge_hashrefs($self->context()->{tags}, $context{tags}),
+        fingerprint     => $context{fingerprint} || $self->context()->{fingerprint} || ['{{ default }}'],
 
-        level       => $self->_validate_level($context{level}) || $self->context()->{level} || 'error',
+        level           => $self->_validate_level($context{level}) || $self->context()->{level} || 'error',
+        environment     => $context{environment} || $self->context()->{environment} || $ENV{SENTRY_ENVIRONMENT},
     };
 
     $event->{message} = _trim($event->{message}, MAX_MESSAGE);
@@ -880,6 +881,11 @@ Array of strings used to control how events aggregate in the sentry web interfac
 
 Timestamp of an event.  ISO 8601 format.  Defaults to the current time.  Invalid values may be discarded silently.
 
+=item C<< environment => 'production' >>
+
+Specify the environment (i.e. I<staging>, I<production>, etc.) that your project is deployed in. More information 
+can be found on the L<Sentry website|https://blog.getsentry.com/2016/07/22/environment-details.html>.
+
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
